@@ -173,7 +173,7 @@ void xdebug_log_stack(const char *error_type_str, char *buffer, const char *erro
 		for (le = XDEBUG_LLIST_HEAD(XG(stack)); le != NULL; le = XDEBUG_LLIST_NEXT(le))
 		{
 			int c = 0; /* Comma flag */
-			int j = 0; /* Counter */
+			unsigned int j = 0; /* Counter */
 			char *tmp_name;
 			xdebug_str log_buffer = {0, 0, NULL};
 
@@ -306,7 +306,7 @@ void xdebug_append_printable_stack(xdebug_str *str, int html TSRMLS_DC)
 		for (le = XDEBUG_LLIST_HEAD(XG(stack)); le != NULL; le = XDEBUG_LLIST_NEXT(le))
 		{
 			int c = 0; /* Comma flag */
-			int j = 0; /* Counter */
+			unsigned int j = 0; /* Counter */
 			char *tmp_name;
 			
 			i = XDEBUG_LLIST_VALP(le);
@@ -509,8 +509,10 @@ void xdebug_init_debugger(TSRMLS_D)
 			zend_alter_ini_entry("max_execution_time", sizeof("max_execution_time"), "0", strlen("0"), PHP_INI_SYSTEM, PHP_INI_STAGE_ACTIVATE);
 			XG(remote_enabled) = 1;
 		}
-	} else {
+	} else if (XG(context).socket == -1) {
 		XDEBUG_LOG_PRINT(XG(remote_log_file), "E: Could not connect to client. :-(\n");
+	} else if (XG(context).socket == -2) {
+		XDEBUG_LOG_PRINT(XG(remote_log_file), "E: Time-out connecting to client. :-(\n");
 	}
 	if (!XG(remote_enabled)) {
 		xdebug_close_log(TSRMLS_C);
@@ -894,6 +896,31 @@ static void xdebug_build_fname(xdebug_func *tmp, zend_execute_data *edata TSRMLS
 					edata->function_state.function->op_array.line_start,
 					edata->function_state.function->op_array.line_end
 				);
+			} else if (strncmp(edata->function_state.function->common.function_name, "call_user_func", 14) == 0) {
+				const char *fname = NULL;
+
+				if (edata->prev_execute_data) {
+					fname = edata->prev_execute_data->function_state.function->op_array.filename;
+				}
+
+				if (
+					!fname &&
+					XDEBUG_LLIST_TAIL(XG(stack)) &&
+					XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))) &&
+					((function_stack_entry*) XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))))->filename
+				) {
+					fname = ((function_stack_entry*) XDEBUG_LLIST_VALP(XDEBUG_LLIST_TAIL(XG(stack))))->filename;
+				}
+
+				if (!fname) {
+					fname = "whoops";
+				}
+				tmp->function = xdebug_sprintf(
+					"%s:{%s:%d}",
+					edata->function_state.function->common.function_name,
+					fname,
+					edata->opline->lineno
+				);
 			} else {
 				tmp->function = xdstrdup(edata->function_state.function->common.function_name);
 			}
@@ -1234,7 +1261,7 @@ PHP_FUNCTION(xdebug_get_stack_depth)
 PHP_FUNCTION(xdebug_get_function_stack)
 {
 	xdebug_llist_element *le;
-	int                   j;
+	unsigned int          j;
 	unsigned int          k;
 	zval                 *frame;
 	zval                 *params;
